@@ -7,12 +7,16 @@ import datetime
 import errno
 import os
 import sys
+import functools
+import types
 
 from nose.plugins.skip import SkipTest
 
-import PIL.Image as Image
-import PIL.ImageFilter as ImageFilter
-
+try:
+    import PIL.Image as Image
+    import PIL.ImageFilter as ImageFilter
+except ImportError:
+    Image = ImageFilter = None
 
 
 import av
@@ -24,6 +28,7 @@ from av.video import VideoFrame
 
 
 is_py3 = sys.version_info[0] > 2
+is_windows = os.name == 'nt'
 
 if not is_py3:
     from itertools import izip as zip
@@ -52,6 +57,7 @@ def makedirs(path):
 
 _start_time = datetime.datetime.now()
 
+
 def _sandbox(timed=False):
     root = os.path.abspath(os.path.join(
         __file__, '..', '..',
@@ -64,17 +70,12 @@ def _sandbox(timed=False):
     ) if timed else root
     if not os.path.exists(sandbox):
         os.makedirs(sandbox)
-        last = os.path.join(root, 'last')
-        try:
-            os.unlink(last)
-        except OSError:
-            pass
-        os.symlink(sandbox, last)
     return sandbox
 
 
 def asset(*args):
-    return os.path.abspath(os.path.join(__file__, '..', 'assets', *args))
+    adir = os.path.dirname(__file__)
+    return os.path.abspath(os.path.join(adir, 'assets', *args))
 
 
 def sandboxed(*args, **kwargs):
@@ -89,16 +90,35 @@ def sandboxed(*args, **kwargs):
     return path
 
 
+class MethodLogger(object):
+
+    def __init__(self, obj):
+        self._obj = obj
+        self._log = []
+
+    def __getattr__(self, name):
+        value = getattr(self._obj, name)
+        if isinstance(value, (types.MethodType, types.FunctionType, types.BuiltinFunctionType, types.BuiltinMethodType)):
+            return functools.partial(self._method, name, value)
+        else:
+            self._log.append(('__getattr__', (name, ), {}))
+            return value
+
+    def _method(self, name, meth, *args, **kwargs):
+        self._log.append((name, args, kwargs))
+        return meth(*args, **kwargs)
+
+    def _filter(self, type_):
+        return [log for log in self._log if log[0] == type_]
+
+
+
 class TestCase(_Base):
 
     @classmethod
     def _sandbox(cls, timed=True):
         path = os.path.join(_sandbox(timed=timed), cls.__name__)
-        try:
-            os.makedirs(path)
-        except OSError as e:
-            if e.errno != errno.EEXIST:
-                raise
+        makedirs(path)
         return path
 
     @property
@@ -121,35 +141,35 @@ class TestCase(_Base):
 
     # Add some of the unittest methods that we love from 2.7.
     if sys.version_info < (2, 7):
-    
+
         def assertIs(self, a, b, msg=None):
             if a is not b:
                 self.fail(msg or '%r at 0x%x is not %r at 0x%x; %r is not %r' % (type(a), id(a), type(b), id(b), a, b))
-    
+
         def assertIsNot(self, a, b, msg=None):
             if a is b:
                 self.fail(msg or 'both are %r at 0x%x; %r' % (type(a), id(a), a))
-        
+
         def assertIsNone(self, x, msg=None):
             if x is not None:
                 self.fail(msg or 'is not None; %r' % x)
-        
+
         def assertIsNotNone(self, x, msg=None):
             if x is None:
                 self.fail(msg or 'is None; %r' % x)
-        
+
         def assertIn(self, a, b, msg=None):
             if a not in b:
                 self.fail(msg or '%r not in %r' % (a, b))
-        
+
         def assertNotIn(self, a, b, msg=None):
             if a in b:
                 self.fail(msg or '%r in %r' % (a, b))
-        
+
         def assertIsInstance(self, instance, types, msg=None):
             if not isinstance(instance, types):
                 self.fail(msg or 'not an instance of %r; %r' % (types, instance))
-        
+
         def assertNotIsInstance(self, instance, types, msg=None):
             if isinstance(instance, types):
                 self.fail(msg or 'is an instance of %r; %r' % (types, instance))
